## Description

Brief description of the changes and the problem they solve.

Fixes #(issue number)

## Type of change

Please delete options that are not relevant:

- [ ] Bug fix (non-breaking change which fixes an issue)
- [ ] New feature (non-breaking change which adds functionality)
- [ ] Breaking change (fix or feature that would cause existing functionality to not work as expected)
- [ ] Documentation update
- [ ] Code refactoring (no functional changes)
- [ ] Performance improvement
- [ ] Test coverage improvement

## Changes Made

- [ ] Added/modified MCP tools
- [ ] Updated models or services
- [ ] Changed configuration handling
- [ ] Updated documentation
- [ ] Added/updated tests
- [ ] Fixed bug in specific component

## Testing

- [ ] All existing tests pass
- [ ] Added tests for new functionality
- [ ] Tested with Claude Desktop integration
- [ ] Manual testing completed

**Test coverage:**
- [ ] Unit tests added/updated
- [ ] Integration tests added/updated
- [ ] Test coverage maintained/improved

**Manual testing performed:**
- [ ] Tested basic functionality
- [ ] Tested edge cases
- [ ] Tested error handling
- [ ] Tested with sample todo.txt files

## Todo.txt Format Compliance

- [ ] Changes maintain todo.txt format compliance
- [ ] No breaking changes to existing todo files
- [ ] New features are backwards compatible
- [ ] Follows todo.txt specification

## Documentation

- [ ] Updated README.md if needed
- [ ] Updated CHANGELOG.md
- [ ] Added docstrings for new functions
- [ ] Updated configuration documentation
- [ ] Added usage examples

## Code Quality

- [ ] Code follows project style guidelines
- [ ] All linting checks pass (`uv run ruff check`)
- [ ] Code is properly formatted (`uv run black`)
- [ ] Type checking passes (`uv run mypy`)
- [ ] No security issues introduced

## Performance Impact

- [ ] No performance regression
- [ ] Performance improvement (if applicable)
- [ ] Memory usage considered
- [ ] File size limits respected

## Breaking Changes

If this is a breaking change, describe:
- What breaks
- Migration path for users
- Version bump rationale

## Additional Notes

Any additional information that reviewers should know:
- Dependencies added/removed
- Configuration changes required
- Known limitations
- Future improvements planned

## Screenshots/Examples (if applicable)

If your changes include UI changes or new functionality, please include:
- Before/after examples
- Command output samples
- Configuration examples

## Checklist

- [ ] My code follows the style guidelines of this project
- [ ] I have performed a self-review of my own code
- [ ] I have commented my code, particularly in hard-to-understand areas
- [ ] I have made corresponding changes to the documentation
- [ ] My changes generate no new warnings
- [ ] I have added tests that prove my fix is effective or that my feature works
- [ ] New and existing unit tests pass locally with my changes
- [ ] Any dependent changes have been merged and published in downstream modules 